@@ -20,21 +20,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""This module effectively implements Microsoft's documentation on Authenticode_PE_.
-
-.. _Authenticode_PE: http://download.microsoft.com/download/9/c/5/9c5b2167-8017-4bae-9fde-d599bac8184a/Authenticode_PE.docx
+"""This module effectively implements Microsoft's documentation on
+`<http://download.microsoft.com/download/9/c/5/9c5b2167-8017-4bae-9fde-d599bac8184a/Authenticode_PE.docx>`_.
 """
 import enum
 import logging
 import pathlib
 
+import mscerts
 from pyasn1.codec.ber import decoder as ber_decoder
 from pyasn1_modules import rfc3161, rfc2315, rfc5652
 
 from signify.authenticode.authroot import CertificateTrustList
 from signify.asn1 import guarded_ber_decode, pkcs7
 from signify.asn1.helpers import accuracy_to_python, patch_rfc5652_signeddata
-from signify.x509 import CertificateName, CertificateStore, VerificationContext, FileSystemCertificateStore
+from signify.x509 import CertificateName, VerificationContext, FileSystemCertificateStore
 from signify.exceptions import AuthenticodeParseError, ParseError, \
     AuthenticodeInconsistentDigestAlgorithmError, AuthenticodeInvalidDigestError, AuthenticodeCounterSignerError, \
     SignedPEParseError, AuthenticodeNotSignedError, CertificateVerificationError, VerificationError
@@ -44,22 +44,42 @@ from signify import asn1
 
 logger = logging.getLogger(__name__)
 
-CERTIFICATE_LOCATION = pathlib.Path(__file__).resolve().parent.parent / "certs" / "authenticode-bundle.pem"
+CERTIFICATE_LOCATION = pathlib.Path(mscerts.where(stl=False))
 TRUSTED_CERTIFICATE_STORE_NO_CTL = FileSystemCertificateStore(location=CERTIFICATE_LOCATION, trusted=True)
 TRUSTED_CERTIFICATE_STORE = FileSystemCertificateStore(location=CERTIFICATE_LOCATION, trusted=True,
                                                        ctl=CertificateTrustList.from_stl_file())
 
 
 class AuthenticodeVerificationResult(enum.Enum):
+    """This represents the result of an Authenticode verification. If everything is OK, it will equal to
+    ``AuthenticodeVerificationResult.OK``, otherwise one of the other enum items will be returned. Remember that only
+    the first exception is processed - there may be more wrong.
+    """
+
     OK = enum.auto()
+    """The signature is valid."""
     NOT_SIGNED = enum.auto()
+    """The provided PE file is not signed."""
     PARSE_ERROR = enum.auto()
+    """The Authenticode signature could not be parsed."""
     VERIFY_ERROR = enum.auto()
+    """The Authenticode signature could not be verified. This is a more generic error than other possible
+    statuses and is used as a catch-all.
+    """
     UNKNOWN_ERROR = enum.auto()
+    """An unknown error occurred during parsing or verifying."""
     CERTIFICATE_ERROR = enum.auto()
+    """An error occurred during the processing of a certificate (e.g. during chain building), or when verifying the
+    certificate's signature.
+    """
     INCONSISTENT_DIGEST_ALGORITHM = enum.auto()
+    """A highly specific error raised when different digest algorithms are used in SignedData, SpcInfo or SignerInfo."""
     INVALID_DIGEST = enum.auto()
+    """The verified digest does not match the calculated digest of the file. This is a tell-tale sign that the file
+    may have been tampered with.
+    """
     COUNTERSIGNER_ERROR = enum.auto()
+    """Something went wrong when verifying the countersignature."""
 
     @classmethod
     def call(cls, function, *args, **kwargs):
@@ -220,7 +240,7 @@ class SpcInfo:
         if 'value' in self.data['data'] and self.data['data']['value'].isValue:
             self.image_data = None
             # TODO: not parsed
-            #image_data = _guarded_ber_decode((self.data['data']['value'], asn1_spec=self.content_type())
+            # image_data = _guarded_ber_decode((self.data['data']['value'], asn1_spec=self.content_type())
 
         self.digest_algorithm = _get_digest_algorithm(self.data['messageDigest']['digestAlgorithm'],
                                                       location="SpcIndirectDataContent.digestAlgorithm")
@@ -522,7 +542,7 @@ class RFC3161SignedData(SignedData):
                                           extended_key_usages=['time_stamping'])
 
         # The context is set correctly by the 'verify' function, including the current certificate store
-        self.signer_info.verify(context)
+        return self.signer_info.verify(context)
 
 
 if __name__ == "__main__":
